@@ -1,4 +1,4 @@
-# $Id: install.py 847 2014-02-03 00:16:45Z mwall $
+# $Id: install.py 964 2014-07-22 02:35:10Z mwall $
 # installer for exfoliation
 # Copyright 2014 Matthew Wall
 
@@ -10,7 +10,7 @@ def loader():
 class ExfoliationInstaller(ExtensionInstaller):
     def __init__(self):
         super(ExfoliationInstaller, self).__init__(
-            version="0.26",
+            version="0.29",
             name='exfoliation',
             description='A minimalist layout with lots of data.',
             author="Matthew Wall",
@@ -26,7 +26,6 @@ class ExfoliationInstaller(ExtensionInstaller):
                             'hilo':'INST_SKIN_ROOT/exfoliation/hilo.inc'}}}},
             files=[('skins/exfoliation',
                     ['skins/exfoliation/almanac.html.tmpl',
-                     'skins/exfoliation/day.html.tmpl',
                      'skins/exfoliation/exfoliation.css',
                      'skins/exfoliation/exfoliation.js',
                      'skins/exfoliation/favicon.ico',
@@ -34,14 +33,12 @@ class ExfoliationInstaller(ExtensionInstaller):
                      'skins/exfoliation/forecast.html.tmpl',
                      'skins/exfoliation/header.inc',
                      'skins/exfoliation/hilo.inc',
+                     'skins/exfoliation/history.html.tmpl',
                      'skins/exfoliation/index.html.tmpl',
                      'skins/exfoliation/links.html.tmpl',
-                     'skins/exfoliation/month.html.tmpl',
                      'skins/exfoliation/skin.conf',
                      'skins/exfoliation/station.html.tmpl',
-                     'skins/exfoliation/week.html.tmpl',
-                     'skins/exfoliation/weewx_rss.xml.tmpl',
-                     'skins/exfoliation/year.html.tmpl']),
+                     'skins/exfoliation/weewx_rss.xml.tmpl']),
                    ('skins/exfoliation/NOAA',
                     ['skins/exfoliation/NOAA/NOAA-YYYY-MM.txt.tmpl',
                      'skins/exfoliation/NOAA/NOAA-YYYY.txt.tmpl']),
